@@ -17,11 +17,10 @@ def load_model(context: Context, **kwargs):
     model_to_use, _ = os.path.splitext(model_to_use)
     model_to_use = RealESRGAN_models[model_to_use]
 
+    half = context.half_precision if context.device != 'cpu' else False
+    model = RealESRGANer(device=torch.device(context.device), scale=4, model_path=model_path, model=model_to_use, pre_pad=0, half=half)
     if context.device == 'cpu':
-        model = RealESRGANer(device=torch.device(context.device), scale=2, model_path=model_path, model=model_to_use, pre_pad=0, half=False) # cpu does not support half
         model.model.to('cpu')
-    else:
-        model = RealESRGANer(device=torch.device(context.device), scale=2, model_path=model_path, model=model_to_use, pre_pad=0, half=context.half_precision)
 
     model.model.name = model_to_use
 
